'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const fetch = require('@whatwg-node/fetch');

function createGenericSDK({ endpoint, fetchFn = fetch.fetch } = {}) {
    return new Proxy({}, {
        get(_target, path) {
            return new Proxy({}, {
                get(_target, method) {
                    return function (requestParams) {
                        var _a, _b;
                        const url = new URL(path, endpoint);
                        for (const pathParamKey in requestParams.PathParams || {}) {
                            const value = (_a = requestParams.PathParams) === null || _a === void 0 ? void 0 : _a[pathParamKey];
                            if (value) {
                                url.pathname = url.pathname.replace(`{${pathParamKey}}`, value);
                            }
                        }
                        for (const queryParamKey in requestParams.QueryParams || {}) {
                            const value = (_b = requestParams.QueryParams) === null || _b === void 0 ? void 0 : _b[queryParamKey];
                            if (value) {
                                if (Array.isArray(value)) {
                                    value.forEach(v => url.searchParams.append(queryParamKey, v));
                                }
                                else {
                                    url.searchParams.append(queryParamKey, value);
                                }
                            }
                        }
                        const requestInit = {
                            method,
                            headers: requestParams.Headers || {},
                        };
                        if (requestParams.JSONBody) {
                            requestInit.body = JSON.stringify(requestParams.JSONBody);
                            requestInit.headers['Content-Type'] = 'application/json';
                        }
                        return fetchFn(url, requestInit);
                    };
                },
            });
        },
    });
}

exports.createGenericSDK = createGenericSDK;
